@@ -26,6 +26,7 @@ from .literals import (
     ErrorCodeType,
     FallbackActionType,
     PushNotificationTypeType,
+    SearchFieldOperatorType,
     SortOrderType,
 )
 
@@ -86,6 +87,7 @@ __all__ = (
     "ListChannelsRequestRequestTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "RedactChannelMessageRequestRequestTypeDef",
+    "SearchFieldTypeDef",
     "UntagResourceRequestRequestTypeDef",
     "UpdateChannelMessageRequestRequestTypeDef",
     "UpdateChannelReadMarkerRequestRequestTypeDef",
@@ -113,6 +115,7 @@ __all__ = (
     "ChannelMembershipForAppInstanceUserSummaryTypeDef",
     "ChannelModeratedByAppInstanceUserSummaryTypeDef",
     "ListChannelsResponseTypeDef",
+    "SearchChannelsResponseTypeDef",
     "ChannelMembershipPreferencesTypeDef",
     "ChannelMessageCallbackTypeDef",
     "SendChannelMessageRequestRequestTypeDef",
@@ -126,6 +129,7 @@ __all__ = (
     "TagResourceRequestRequestTypeDef",
     "GetMessagingSessionEndpointResponseTypeDef",
     "ProcessorConfigurationTypeDef",
+    "SearchChannelsRequestRequestTypeDef",
     "BatchCreateChannelMembershipResponseTypeDef",
     "ListChannelBansResponseTypeDef",
     "DescribeChannelBanResponseTypeDef",
@@ -729,6 +733,15 @@ RedactChannelMessageRequestRequestTypeDef = TypedDict(
     },
 )
 
+SearchFieldTypeDef = TypedDict(
+    "SearchFieldTypeDef",
+    {
+        "Key": Literal["MEMBERS"],
+        "Values": Sequence[str],
+        "Operator": SearchFieldOperatorType,
+    },
+)
+
 UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
@@ -774,14 +787,14 @@ _RequiredUpdateChannelRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateChannelRequestRequestTypeDef",
     {
         "ChannelArn": str,
-        "Name": str,
-        "Mode": ChannelModeType,
         "ChimeBearer": str,
     },
 )
 _OptionalUpdateChannelRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateChannelRequestRequestTypeDef",
     {
+        "Name": str,
+        "Mode": ChannelModeType,
         "Metadata": str,
     },
     total=False,
@@ -1008,6 +1021,15 @@ ListChannelsResponseTypeDef = TypedDict(
     },
 )
 
+SearchChannelsResponseTypeDef = TypedDict(
+    "SearchChannelsResponseTypeDef",
+    {
+        "Channels": List[ChannelSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 ChannelMembershipPreferencesTypeDef = TypedDict(
     "ChannelMembershipPreferencesTypeDef",
     {
@@ -1151,6 +1173,9 @@ _OptionalCreateChannelRequestRequestTypeDef = TypedDict(
         "Privacy": ChannelPrivacyType,
         "Metadata": str,
         "Tags": Sequence[TagTypeDef],
+        "ChannelId": str,
+        "MemberArns": Sequence[str],
+        "ModeratorArns": Sequence[str],
     },
     total=False,
 )
@@ -1193,6 +1218,29 @@ ProcessorConfigurationTypeDef = TypedDict(
     },
 )
 
+_RequiredSearchChannelsRequestRequestTypeDef = TypedDict(
+    "_RequiredSearchChannelsRequestRequestTypeDef",
+    {
+        "Fields": Sequence[SearchFieldTypeDef],
+    },
+)
+_OptionalSearchChannelsRequestRequestTypeDef = TypedDict(
+    "_OptionalSearchChannelsRequestRequestTypeDef",
+    {
+        "ChimeBearer": str,
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class SearchChannelsRequestRequestTypeDef(
+    _RequiredSearchChannelsRequestRequestTypeDef, _OptionalSearchChannelsRequestRequestTypeDef
+):
+    pass
+
+
 BatchCreateChannelMembershipResponseTypeDef = TypedDict(
     "BatchCreateChannelMembershipResponseTypeDef",
     {
